==> subtitle-download-1.0.2-sources.jar: com/transsion/subtitle_download/api/SubtitleDownloadApi.kt <==
package com.transsion.subtitle_download.api

import com.transsion.subtitle_download.bean.SubtitleListBean
import com.tn.lib.net.bean.BaseDto
import com.tn.lib.net.cons.NetConst
import retrofit2.http.GET
import retrofit2.http.Query

/**
 * @author: zhangxinbing
 * @date : 2024/5/13 16:37
 * @description: 资源字幕请求
 */
internal interface SubtitleDownloadApi {

    /**
     * 获取字幕下载列表
     */
    @GET("/wefeed-mobile-bff/subject-api/get-ext-captions")
    suspend fun getSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("subjectId") subjectId: String?,
        @Query("resourceId") resourceId: String?,
        @Query("episode") episode: Int = 0
    ): BaseDto<SubtitleListBean>

    /**
     * 获取字幕下载列表
     */
    @GET("/wefeed-mobile-bff/subject-api/get-stream-captions")
    suspend fun getStreamSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("subjectId") subjectId: String?,
        @Query("streamId") resourceId: String?
    ): BaseDto<SubtitleListBean>

    /**
     * 获取短剧字幕下载列表
     */
    @GET("/wefeed-mobile-bff/shorts/get-mini-captions")
    suspend fun getMbShortTVSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("miniId") miniId: String?,
    ): BaseDto<SubtitleListBean>


    /**
     * 获取短剧字幕下载列表
     */
    @GET("/wefeed-short-bff/shorts/get-mini-captions")
    suspend fun getNovelShortTVSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("miniId") miniId: String?,
    ): BaseDto<SubtitleListBean>


}

==> subtitle-download-1.0.3-sources.jar: com/transsion/subtitle_download/api/SubtitleDownloadApi.kt <==
package com.transsion.subtitle_download.api

import com.transsion.subtitle_download.bean.SubtitleListBean
import com.tn.lib.net.bean.BaseDto
import com.tn.lib.net.cons.NetConst
import retrofit2.http.GET
import retrofit2.http.Query

/**
 * @author: zhangxinbing
 * @date : 2024/5/13 16:37
 * @description: 资源字幕请求
 */
internal interface SubtitleDownloadApi {

    /**
     * 获取字幕下载列表
     */
    @GET("/wefeed-mobile-bff/subject-api/get-ext-captions")
    suspend fun getSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("subjectId") subjectId: String?,
        @Query("resourceId") resourceId: String?,
        @Query("episode") episode: Int = 0
    ): BaseDto<SubtitleListBean>

    /**
     * 获取字幕下载列表
     */
    @GET("/wefeed-mobile-bff/subject-api/get-stream-captions")
    suspend fun getStreamSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("subjectId") subjectId: String?,
        @Query("streamId") resourceId: String?
    ): BaseDto<SubtitleListBean>

    /**
     * 获取短剧字幕下载列表
     */
    @GET("/wefeed-mobile-bff/shorts/get-mini-captions")
    suspend fun getMbShortTVSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("miniId") miniId: String?,
    ): BaseDto<SubtitleListBean>


    /**
     * 获取短剧字幕下载列表
     */
    @GET("/wefeed-short-bff/shorts/get-mini-captions")
    suspend fun getNovelShortTVSubtitles(
        @Query(NetConst.HOST) host: String,
        @Query("miniId") miniId: String?,
    ): BaseDto<SubtitleListBean>


    /**
     * ugc模式字幕列表
     * @param id 资源id或流媒体id
     * @param idType :ResourceId/StreamId/VideoId
     */
    @GET("/wefeed-mobile-bff/ugc/video/caption")
    suspend fun getUGCVideoSubtitles(
        @Query("ugcVideoId") ugcVideoId: String?,
        @Query("id") id: String?,
        @Query("idType") idType: String?,
        @Query(NetConst.HOST) host: String
    ): BaseDto<SubtitleListBean>

}
